==> fastestimator-nightly-1.5.0.dev202302211323.tar.gz: fastestimator-nightly-1.5.0.dev202302211323/fastestimator/dataset/data/__init__.py <==
# Copyright 2019 The FastEstimator Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from typing import TYPE_CHECKING

import lazy_loader as lazy

__getattr__, __dir__, __all__ = lazy.attach(__name__,
                                            submodules={'breast_cancer', 'cifair10', 'cifair100', 'cifar10',
                                                        'cifar100', 'cub200','em_3d', 'food101', 'horse2zebra', 'imdb_review',
                                                        'mendeley', 'mitmovie_ner', 'mnist', 'montgomery', 'mscoco',
                                                        'nih_chestxray', 'omniglot', 'penn_treebank', 'shakespeare',
                                                        'skl_digits', 'svhn', 'svhn_cropped', 'tednmt', 'usps', 'pascal_voc'}
                                            )

if TYPE_CHECKING:
    from fastestimator.dataset.data import breast_cancer, cifair10, cifair100, cifar10, cifar100, cub200, em_3d, \
        food101, horse2zebra, imdb_review, mendeley, mitmovie_ner, mnist, montgomery, mscoco, nih_chestxray, omniglot, \
        penn_treebank, shakespeare, skl_digits, svhn, svhn_cropped, tednmt, usps, pascal_voc

==> fastestimator-nightly-1.6.0.dev202307151357.tar.gz: fastestimator-nightly-1.6.0.dev202307151357/fastestimator/dataset/data/__init__.py <==
# Copyright 2019 The FastEstimator Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from typing import TYPE_CHECKING

import lazy_loader as lazy

__getattr__, __dir__, __all__ = lazy.attach(__name__,
                                            submodules={'breast_cancer', 'cifair10', 'cifair100', 'cifar10',
                                                        'cifar100', 'cub200','em_3d', 'food101', 'horse2zebra', 'imdb_review',
                                                        'mendeley', 'mitmovie_ner', 'mnist', 'montgomery', 'mscoco',
                                                        'nih_chestxray', 'omniglot', 'penn_treebank', 'shakespeare',
                                                        'skl_digits', 'svhn', 'svhn_cropped', 'tednmt', 'usps', 'pascal_voc', 'medmnist'}
                                            )

if TYPE_CHECKING:
    from fastestimator.dataset.data import breast_cancer, cifair10, cifair100, cifar10, cifar100, cub200, em_3d, \
        food101, horse2zebra, imdb_review, mendeley, mitmovie_ner, mnist, montgomery, mscoco, nih_chestxray, omniglot, \
        penn_treebank, shakespeare, skl_digits, svhn, svhn_cropped, tednmt, usps, pascal_voc, medmnist
